package com.example.gertec_tsg800;

import android.Manifest;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Build;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;

import com.google.zxing.integration.android.IntentIntegrator;
import com.google.zxing.integration.android.IntentResult;

import java.util.ArrayList;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import static android.app.Activity.RESULT_OK;
import static android.hardware.Camera.Parameters.FLASH_MODE_ON;

/** GertecPlugin */
public class GertecTsg800Plugin implements FlutterPlugin, PluginRegistry.ActivityResultListener,
    PluginRegistry.RequestPermissionsResultListener, ActivityAware, MethodCallHandler {
  public static final String G700 = "GPOS700";
  public static final String G800 = "Smart G800";
  private static final String version = "RC03";
  public static String Model = Build.MODEL;
  private Context applicationContext;
  private MethodChannel methodChannel;
  private IntentIntegrator qrScan;
  private static Result pendingResult;
  private ConfigPrint configPrint = new ConfigPrint();
  private GertecPrinter gertecPrinter;
  private Activity myActivity;
  private String resultado_Leitor;
  public static ActivityPluginBinding _binding;

  private String tipo;
  private static final int REQUEST_CODE_SCAN_ACTIVITY = 2777;
  private static final int REQUEST_CODE_CAMERA_PERMISSION = 3777;
  private ArrayList<String> arrayListTipo;

  /** Registrar plugin em projetos que não tenham a incorporação V2 Android **/
  public static void registerWith(Registrar registrar) {
    final GertecTsg800Plugin instance = new GertecTsg800Plugin();
    instance.onAttachedToEngine(registrar.activeContext(), registrar.messenger());
  }

  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if(_binding!=null){
        _binding.addActivityResultListener(this);
    }
    Intent intent = null;
    String mensagem = "";
    pendingResult = null;
    pendingResult = result;
    try {
      switch (call.method) {
        case "lerNfc":
          try {
            intent = new Intent(myActivity, NfcLeitura.class);
            myActivity.startActivityForResult (intent, 111);
          } catch (Exception e) {
            e.printStackTrace();
            result.notImplemented();
          }
          break;
        case "gravarNfc":
          String mensagemGravar = call.argument("mensagemGravar");
          try {
            intent = new Intent(myActivity, NfcGravacao.class);
            intent.putExtra("mensagemGravar", mensagemGravar);
            myActivity.startActivity(intent);
          } catch (Exception e) {
            e.printStackTrace();
            result.notImplemented();
          }
          break;
        case "formatarNfc":
          try {
            intent = new Intent(myActivity, NfcFormatar.class);
            myActivity.startActivity(intent);
          } catch (Exception e) {
            e.printStackTrace();
            result.notImplemented();
          }
          break;
        case "testeNfc":
          try {
            intent = new Intent(myActivity, NfcLerGravar.class);
            myActivity.startActivity(intent);
          } catch (Exception e) {
            e.printStackTrace();
            result.notImplemented();
          }
          break;
        case "statusImpressora":
          try {
            gertecPrinter.getStatusImpressora();
            result.success(gertecPrinter.isImpressoraOK());
          } catch (Exception e) {
            e.printStackTrace();
          }
          break;
        case "imprimirTexto":
          gertecPrinter.getStatusImpressora();
          if (gertecPrinter.isImpressoraOK()) {
            mensagem = call.argument("mensagem");
            String alinhar = call.argument("alinhar");
            int size = call.argument("size");
            String fontFamily = call.argument("font");
            Boolean negrito = call.argument("negrito");
            Boolean italico = call.argument("italico");
            Boolean sublinhado = call.argument("sublinhado");
            this.configPrint.setFonte(fontFamily);
            this.configPrint.setTamanho(size);
            this.configPrint.setAlinhamento(alinhar);
            this.configPrint.setNegrito(negrito);
            this.configPrint.setItalico(italico);
            this.configPrint.setSublinhado(sublinhado);
            this.gertecPrinter.setConfigImpressao(configPrint);
            this.gertecPrinter.imprimeTexto(mensagem);
            this.gertecPrinter.avancaLinha(150);
            this.gertecPrinter.ImpressoraOutput();
          }
          break;
        case "imprimirImagem":
          gertecPrinter.getStatusImpressora();
          if (gertecPrinter.isImpressoraOK()) {
            gertecPrinter.imprimeImagem(call.argument("codigoImagem"));
            gertecPrinter.ImpressoraOutput();
          }
          break;
        case "leitorV1":
          tipo = call.argument("tipoLeitura");
          startCamera();
          break;
        case "leitorV2":
          intent = new Intent(myActivity, CodigoBarrasV2.class);
          myActivity.startActivity(intent);
          result.success("Camera Aberta");
          break;
        case "imprimirCodigoDeBarra":
          gertecPrinter.getStatusImpressora();
          if (gertecPrinter.isImpressoraOK()) {
            mensagem = call.argument("mensagem");
            int height = call.argument("height");
            int width = call.argument("width");
            String barCode = call.argument("barCode");
            gertecPrinter.imprimeBarCode(mensagem, height, width, barCode);
            gertecPrinter.ImpressoraOutput();
          }
          break;
      }
    } catch (Exception e) {
      e.getLocalizedMessage();
    }
  }

  /** Registrar plugin em projetos que não tenham a incorporação V2 Android **/
  public void onAttachedToEngine(FlutterPluginBinding binding) {
    onAttachedToEngine(binding.getApplicationContext(), binding.getBinaryMessenger());
    this.arrayListTipo = new ArrayList<String>();
  }

  private void onAttachedToEngine(Context applicationContext, BinaryMessenger messenger) {
    this.applicationContext = applicationContext;
    methodChannel = new MethodChannel(messenger, "gertec_tsg800");
    methodChannel.setMethodCallHandler(this);
  }

  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
  }

  private void ImprimeTodasAsFucoes() {
    configPrint.setItalico(false);
    configPrint.setNegrito(true);
    configPrint.setTamanho(20);
    configPrint.setFonte("MONOSPACE");
    gertecPrinter.setConfigImpressao(configPrint);
    try {
      gertecPrinter.getStatusImpressora();
      // Imprimindo Imagem
      configPrint.setiWidth(300);
      configPrint.setiHeight(130);
      configPrint.setAlinhamento("CENTER");
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("==[Iniciando Impressao Imagem]==");
      gertecPrinter.imprimeImagem("logogertec");
      gertecPrinter.avancaLinha(10);
      gertecPrinter.imprimeTexto("====[Fim Impressão Imagem]====");
      gertecPrinter.avancaLinha(10);
      // Fim Imagem

      // Impressão Centralizada
      configPrint.setAlinhamento("CENTER");
      configPrint.setTamanho(30);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("CENTRALIZADO");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão Centralizada

      // Impressão Esquerda
      configPrint.setAlinhamento("LEFT");
      configPrint.setTamanho(40);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("ESQUERDA");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão Esquerda

      // Impressão Direita
      configPrint.setAlinhamento("RIGHT");
      configPrint.setTamanho(20);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("DIREITA");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão Direita

      // Impressão Negrito
      configPrint.setNegrito(true);
      configPrint.setAlinhamento("LEFT");
      configPrint.setTamanho(20);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("=======[Escrita Netrigo]=======");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão Negrito

      // Impressão Italico
      configPrint.setNegrito(false);
      configPrint.setItalico(true);
      configPrint.setAlinhamento("LEFT");
      configPrint.setTamanho(20);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("=======[Escrita Italico]=======");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão Italico

      // Impressão Italico
      configPrint.setNegrito(false);
      configPrint.setItalico(false);
      configPrint.setSublinhado(true);
      configPrint.setAlinhamento("LEFT");
      configPrint.setTamanho(20);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("======[Escrita Sublinhado]=====");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão Italico

      // Impressão BarCode 128
      configPrint.setNegrito(false);
      configPrint.setItalico(false);
      configPrint.setSublinhado(false);
      configPrint.setAlinhamento("CENTER");
      configPrint.setTamanho(20);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("====[Codigo Barras CODE 128]====");
      gertecPrinter.imprimeBarCode("12345678901234567890", 120, 120, "CODE_128");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão BarCode 128

      // Impressão Normal
      configPrint.setNegrito(false);
      configPrint.setItalico(false);
      configPrint.setSublinhado(true);
      configPrint.setAlinhamento("LEFT");
      configPrint.setTamanho(20);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("=======[Escrita Normal]=======");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão Normal

      // Impressão Normal
      configPrint.setNegrito(false);
      configPrint.setItalico(false);
      configPrint.setSublinhado(true);
      configPrint.setAlinhamento("LEFT");
      configPrint.setTamanho(20);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("=========[BlankLine 50]=========");
      gertecPrinter.avancaLinha(50);
      gertecPrinter.imprimeTexto("=======[Fim BlankLine 50]=======");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão Normal

      // Impressão BarCode 13
      configPrint.setNegrito(false);
      configPrint.setItalico(false);
      configPrint.setSublinhado(false);
      configPrint.setAlinhamento("CENTER");
      configPrint.setTamanho(20);
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("=====[Codigo Barras EAN13]=====");
      gertecPrinter.imprimeBarCode("7891234567895", 120, 120, "EAN_13");
      gertecPrinter.avancaLinha(10);
      // Fim Impressão BarCode 128

      // Impressão BarCode 13
      gertecPrinter.setConfigImpressao(configPrint);
      gertecPrinter.imprimeTexto("===[Codigo QrCode Gertec LIB]==");
      gertecPrinter.avancaLinha(10);
      gertecPrinter.imprimeBarCode("Gertec Developer Partner LIB", 240, 240, "QR_CODE");

      configPrint.setNegrito(false);
      configPrint.setItalico(false);
      configPrint.setSublinhado(false);
      configPrint.setAlinhamento("CENTER");
      configPrint.setTamanho(20);
      gertecPrinter.imprimeTexto("===[Codigo QrCode Gertec IMG]==");
      gertecPrinter.imprimeBarCodeIMG("Gertec Developer Partner IMG", 240, 240, "QR_CODE");
      gertecPrinter.avancaLinha(100);
    } catch (Exception e) {
      e.printStackTrace();
    }
  }

  private void startCamera() {
    this.arrayListTipo.add(this.tipo);
    qrScan = new IntentIntegrator(this.myActivity);
    qrScan.setPrompt("Digitalizar o código ");
    qrScan.setBeepEnabled(true);
    qrScan.setBarcodeImageEnabled(true);
    qrScan.setTimeout(30000); // 30 * 1000 => 3 minuto
    qrScan.addExtra("FLASH_MODE_ON", FLASH_MODE_ON);
    qrScan.initiateScan(this.arrayListTipo);
  }

  /** Registrar Activity **/
  public void onAttachedToActivity(ActivityPluginBinding binding) {
    _binding = binding;
    this.myActivity = binding.getActivity();
    gertecPrinter = new GertecPrinter(myActivity);
    gertecPrinter.setConfigImpressao(configPrint);
  }

  public void onDetachedFromActivityForConfigChanges() {
  }

  public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {
  }

  public void onDetachedFromActivity() {
  }

  @RequiresApi(api = Build.VERSION_CODES.M)
  public boolean onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
    myActivity.requestPermissions(new String[] { Manifest.permission.CAMERA }, REQUEST_CODE_CAMERA_PERMISSION);
    return false;
  }

  public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
    if (requestCode == 111) {
      if (resultCode == RESULT_OK && data != null) {
        pendingResult.success(data.getStringExtra("mensagemLeitura"));
      }else{
        pendingResult.notImplemented();
      }
    } else {
      IntentResult intentResult = IntentIntegrator.parseActivityResult(requestCode, resultCode, data);
      if (intentResult != null) {
        // if qrcode has nothing in it
        if (intentResult.getContents() == null) {
          // Toast.makeText(this, "Result Not Found", Toast.LENGTH_LONG).show();
          resultado_Leitor = (this.tipo + ": Não foi possível ler o código.\n");
        } else {
          // if qr contains data
          try {
            resultado_Leitor = this.tipo + ": " + intentResult.getContents() + "\n";
          } catch (Exception e) {
            e.printStackTrace();
            resultado_Leitor = this.tipo + ": Erro " + e.getMessage() + "\n";
          }
        }
      } else {
        resultado_Leitor = this.tipo + ": Não foi possível fazer a leitura.\n";
      }
      pendingResult.success(resultado_Leitor);
      this.arrayListTipo.clear();
    }
    return false;
  }
}